##
##  mediamtx.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2025 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
%define       V_mediamtx_base  1.12.0
%define       V_mediamtx_snap  20250415

#   package information
Name:         mediamtx
Summary:      Media Streaming Server
URL:          https://github.com/bluenviron/mediamtx
Vendor:       aler9
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Multimedia
License:      MIT
Version:      %{V_mediamtx_base}.%{V_mediamtx_snap}
Release:      20250415

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/mediamtx/mediamtx-%{V_mediamtx_snap}.tar.xz
Source1:      mediamtx.yaml
Source2:      rc.mediamtx

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101

%description
    MediaMTX is a ready-to-use and zero-dependency server and proxy
    that allows users to publish, read and proxy live video and audio
    streams.

%track
    prog mediamtx:base = {
        version   = %{V_mediamtx_base}
        url       = https://github.com/bluenviron/mediamtx/releases
        regex     = tree/v(\d+\.\d+\.\d+)
    }
    prog mediamtx:snap = {
        version   = %{V_mediamtx_snap}
        url       = http://download.openpkg.org/components/versioned/mediamtx/
        regex     = mediamtx-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n mediamtx

%build
    #   build program
    export GOPATH=`pwd`
    cd $GOPATH/src/github.com/bluenviron/mediamtx/internal/servers/hls
    go run hlsjsdownloader/main.go
    cd $GOPATH/src/github.com/bluenviron/mediamtx/internal/core
    echo "%{version} (OpenPKG)" >VERSION
    cd $GOPATH/src/github.com/bluenviron/mediamtx
    go build -v -o mediamtx .

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/mediamtx \
        $RPM_BUILD_ROOT%{l_prefix}/var/mediamtx/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/mediamtx/run

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/bluenviron/mediamtx/mediamtx \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/

    #   install configuration files
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE mediamtx.yaml} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/mediamtx/

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.mediamtx} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/mediamtx/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/mediamtx/*'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} mediamtx status 2>/dev/null`
    [ ".$mediamtx_active" = .yes ] && %{l_rc} mediamtx restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} mediamtx stop 2>/dev/null
    rm -rf $RPM_INSTALL_PREFIX/var/mediamtx/log/*  >/dev/null 2>&1 || true
    rm -rf $RPM_INSTALL_PREFIX/var/mediamtx/run/*  >/dev/null 2>&1 || true
    exit 0

